import os
import os.path
import sys
import glob
import logging

from ._version import get_versions
__version__ = get_versions()['version']
del get_versions

# -----------------------------------------------------------------------------
#           check_installation_called_from_sasktranif
# -----------------------------------------------------------------------------


def check_installation_called_from_sasktranif(SKTRAN_IFCreateRegistryEntriesForDLL, registry):

    dirname = os.path.dirname(__file__)
    firstimefile = os.path.join(dirname, "sasktran_tir_firsttime.sktran")
    if os.path.exists(firstimefile):
        # check if sasktran_core has been configured; if sasktran_tir is configured before sasktran_core, the sasktran_tir
        # configuration is overwritten by the sasktran_core configuration
        try:
            module = __import__('sasktran_core')
            ok = 'check_installation_called_from_sasktranif' in dir(module)
            if (ok):
                module.check_installation_called_from_sasktranif(SKTRAN_IFCreateRegistryEntriesForDLL, registry)
            else:
                logging.info(
                    'Module sasktran_core was not properly imported by sasktranif as it does not have a method <check_installation_called_from_sasktranif> to check the modules installation')
        except:
            logging.info(
                'Module sasktran_core was not loaded and threw an exception. That indicates an installation problem')

        print("First Time Setup: Initiliazing Sasktran TIR registry settings")
        dllnames = glob.glob(dirname + os.sep + "*sasktranif_tir_interface.*")          # Search that directory for the core components DLL or shareable object
        dllname = dllnames[0]                                                           # We must find at least 1 (or fail)
        SKTRAN_IFCreateRegistryEntriesForDLL(dllname, dllname)                     # param[0] =  full path name of this DLL.
        os.unlink(firstimefile)
        print("First Time Setup: Sasktran TIR initialization is complete.")
